==> fengoffice_1.7.5.zip: fengoffice/language/es_es/fields.php <==
<?php return array(
	'field Companies name' => 'Nombre',
	'field Companies address' => 'Dirección',
	'field Companies address2' => 'Dirección 2',
	'field Companies city' => 'Ciudad',
	'field Companies state' => 'Estado',
	'field Companies zipcode' => 'Código postal',
	'field Companies country' => 'País',
	'field Companies phone_number' => 'Teléfono',
	'field Companies fax_number' => 'Fax',
	'field Companies email' => 'Correo electrónico',
	'field Companies homepage' => 'Sitio web',
	'field Companies notes' => 'Notas',
	'field Companies created_on' => 'Creado',
	'field Companies updated_on' => 'Actualizado',
	'field Companies archived_on' => 'Archivado',
	'field Companies archived_by_id' => 'Archivado por',
	'field Contacts firstname' => 'Nombre',
	'field Contacts lastname' => 'Apellido',
	'field Contacts email' => 'Correo electrónico',
	'field Contacts w_web_page' => 'Sitio web del trabajo',
	'field Contacts w_address' => 'Dirección del trabajo',
	'field Contacts w_city' => 'Ciudad del trabajo',
	'field Contacts w_state' => 'Estado del trabajo',
	'field Contacts w_zipcode' => 'Código postal del trabajo',
	'field Contacts w_country' => 'País del trabajo',
	'field Contacts w_phone_number' => 'Teléfono del trabajo',
	'field Contacts w_phone_number2' => 'Teléfono 2 del trabajo',
	'field Contacts w_fax_number' => 'Fax del trabajo',
	'field Contacts w_assistant_number' => 'Asistente del trabajo',
	'field Contacts w_callback_number' => 'Llamado del trabajo',
	'field Contacts h_web_page' => 'Sitio web del hogar',
	'field Contacts h_address' => 'Dirección del hogar',
	'field Contacts h_city' => 'Ciudad del hogar',
	'field Contacts h_state' => 'Estado del hogar',
	'field Contacts h_zipcode' => 'Código postal del hogar',
	'field Contacts h_country' => 'País del hogar',
	'field Contacts h_phone_number' => 'Teléfono del hogar',
	'field Contacts h_phone_number2' => 'Teléfono 2 del hogar',
	'field Contacts h_fax_number' => 'Fax del hogar',
	'field Contacts h_mobile_number' => 'Teléfono móvil del hogar',
	'field Contacts h_pager_number' => 'Pager del hogar',
	'field Contacts o_web_page' => 'Otro sitio web',
	'field Contacts o_address' => 'Otra dirección',
	'field Contacts o_city' => 'Otra ciudad',
	'field Contacts o_state' => 'Otro estado',
	'field Contacts o_zipcode' => 'Otro código postal',
	'field Contacts o_country' => 'Otro país',
	'field Contacts o_phone_number' => 'Otro teléfono',
	'field Contacts o_phone_number2' => 'Otro teléfono 2',
	'field Contacts o_fax_number' => 'Otro fax',
	'field Contacts o_birthday' => 'Fecha de nacimiento',
	'field Contacts email2' => 'Dirección de correo 2',
	'field Contacts email3' => 'Dirección de correo 3',
	'field Contacts job_title' => 'Título',
	'field Contacts department' => 'Departamento',
	'field Contacts middlename' => 'Segundo nombre',
	'field Contacts notes' => 'Notas',
	'field Contacts created_on' => 'Creado',
	'field Contacts updated_on' => 'Actualizado',
	'field Contacts archived_on' => 'Archivado',
	'field Contacts archived_by_id' => 'Archivado por',
	'field MailContents from' => 'De',
	'field MailContents from_name' => 'De nombre',
	'field MailContents to' => 'Para',
	'field MailContents date' => 'Fecha',
	'field MailContents sent_date' => 'Fecha de enviado',
	'field MailContents subject' => 'Asunto',
	'field MailContents content' => 'Contenido',
	'field MailContents body' => 'Cuerpo',
	'field MailContents body_plain' => 'Cuerpo plano',
	'field MailContents body_html' => 'Cuerpo HTML',
	'field MailContents has_attachments' => 'Tiene adjuntos',
	'field MailContents size' => 'Tamaño',
	'field MailContents state' => 'Estado',
	'field MailContents is_deleted' => 'Eliminado',
	'field MailContents is_shared' => 'Compartido',
	'field MailContents imap_folder_name' => 'Nombre de carpeta IMAP',
	'field MailContents account_email' => 'Cuenta de correo',
	'field MailContents created_on' => 'Creado',
	'field MailContents cc' => 'CC',
	'field MailContents bcc' => 'BCC',
	'field MailContents archived_on' => 'Archivado',
	'field MailContents archived_by_id' => 'Archivado por',
	'field MailContents sync' => 'Sincronizado',
	'field ProjectEvents duration' => 'Fin',
	'field ProjectEvents start' => 'Comienzo',
	'field ProjectEvents subject' => 'Asunto',
	'field ProjectEvents repeat_forever' => 'Repetir para siempre',
	'field ProjectEvents description' => 'Descripción',
	'field ProjectEvents private' => 'Privado',
	'field ProjectEvents repeat_end' => 'Fin de repetición',
	'field ProjectEvents repeat_num' => 'Número de repetición',
	'field ProjectEvents repeat_d' => 'Día de repetición',
	'field ProjectEvents repeat_m' => 'Mes de repetición',
	'field ProjectEvents repeat_y' => 'Año de repetición',
	'field ProjectEvents repeat_h' => 'Hora de repetición',
	'field ProjectEvents created_on' => 'Creado',
	'field ProjectEvents updated_on' => 'Actualizado',
	'field ProjectEvents archived_on' => 'Archivado',
	'field ProjectEvents archived_by_id' => 'Archivado por',
	'field ProjectFiles filename' => 'Nombre de archivo',
	'field ProjectFiles description' => 'Descripción',
	'field ProjectFiles is_important' => 'Importante',
	'field ProjectFiles is_locked' => 'Bloqueado',
	'field ProjectFiles is_visible' => 'Visible',
	'field ProjectFiles expiration_time' => 'Tiempo de expiración',
	'field ProjectFiles comments_enabled' => 'Comentarios habilitados',
	'field ProjectFiles anonymous_comments_enabled' => 'Comentarios anónimos habilitados',
	'field ProjectFiles url' => 'Url',
	'field ProjectFiles created_on' => 'Creado',
	'field ProjectFiles updated_on' => 'Actualizado',
	'field ProjectFiles checked_out_on' => 'Bloqueado',
	'field ProjectFiles archived_on' => 'Archivado',
	'field ProjectFiles archived_by_id' => 'Archivado por',
	'field ProjectFileRevisions filecontent' => 'Contenido del documento',
	'field ProjectMilestones name' => 'Nombre',
	'field ProjectMilestones description' => 'Descripción',
	'field ProjectMilestones due_date' => 'Fecha de límite',
	'field ProjectMilestones completed_on' => 'Completado',
	'field ProjectMilestones is_template' => 'Es plantilla',
	'field ProjectMilestones created_on' => 'Creado',
	'field ProjectMilestones updated_on' => 'Actualizado',
	'field ProjectMilestones archived_on' => 'Archivado',
	'field ProjectMilestones archived_by_id' => 'Archivado por',
	'field ProjectMessages title' => 'Título',
	'field ProjectMessages text' => 'Texto',
	'field ProjectMessages additional_text' => 'Texto adicional',
	'field ProjectMessages is_important' => 'Es importante',
	'field ProjectMessages comments_enabled' => 'Comentarios habilitados',
	'field ProjectMessages anonymous_comments_enabled' => 'Comentarios anónimos habilitados',
	'field ProjectMessages created_on' => 'Creado',
	'field ProjectMessages updated_on' => 'Actualizado',
	'field ProjectMessages archived_on' => 'Archivado',
	'field ProjectMessages archived_by_id' => 'Archivado por',
	'field ProjectTasks text' => 'Texto',
	'field ProjectTasks completed_on' => 'Completada',
	'field ProjectTasks due_date' => 'Fecha de límite',
	'field ProjectTasks start_date' => 'Fecha de comienzo',
	'field ProjectTasks created_on' => 'Creada',
	'field ProjectTasks updated_on' => 'Actualizada',
	'field ProjectTasks order' => 'Orden',
	'field ProjectTasks title' => 'Título',
	'field ProjectTasks started_on' => 'Comenzado',
	'field ProjectTasks priority' => 'Prioridad',
	'field ProjectTasks assigned_on' => 'Asignado',
	'field ProjectTasks time_estimate' => 'Tiempo estimado',
	'field ProjectTasks is_template' => 'Es plantilla',
	'field ProjectTasks archived_on' => 'Archivado',
	'field ProjectTasks archived_by_id' => 'Archivado por',
	'field ProjectTasks object_subtype' => 'Tipo de objeto',
	'field ProjectTasks status' => 'Estado',
	'field Users username' => 'Nombre de usuario',
	'field Users email' => 'Correo electrónico',
	'field Users display_name' => 'Nombre desplegado',
	'field Users title' => 'Título',
	'field Users created_on' => 'Creado',
	'field Users updated_on' => 'Actualizado',
	'field Users last_login' => 'Última conexión',
	'field Users last_visit' => 'Última visita',
	'field Users last_activity' => 'Última actividad',
	'field Users can_edit_company_data' => 'Puede editar información de empresa propietaria',
	'field Users can_manage_workspaces' => 'Puede manejar áreas de trabajo',
	'field Users can_manage_security' => 'Puede manejar seguridad',
	'field Users can_manage_configuration' => 'Puede manejar configuración',
	'field Users auto_assign' => 'Auto asignar',
	'field Users can_manage_contacts' => 'Puede manejar contactos',
	'field Users can_manage_templates' => 'Puede manejar plantillas',
	'field Users can_manage_reports' => 'Puede manejar reportes',
	'field ProjectWebPages url' => 'Url',
	'field ProjectWebPages title' => 'Título',
	'field ProjectWebPages description' => 'Descripción',
	'field ProjectWebPages created_on' => 'Creado',
	'field ProjectWebPages updated_on' => 'Actualizado',
	'field ProjectWebPages archived_on' => 'Archivado',
	'field ProjectWebPages archived_by_id' => 'Archivado por',
	'field Projects name' => 'Nombre',
	'field Projects description' => 'Descripción',
	'field Projects show_description_in_overview' => 'Mostrar descripción en vista general',
	'field Projects completed_on' => 'Completado',
	'field Projects created_on' => 'Creado',
	'field Projects updated_on' => 'Actualizado',
	'field Projects archived_on' => 'Archivado',
	'field Projects archived_by_id' => 'Archivado por',
	'field ProjectWebpages url' => 'Url',
	'field ProjectWebpages title' => 'Título',
	'field ProjectWebpages description' => 'Descripción',
	'field ProjectWebpages created_on' => 'Creado el',
	'field ProjectWebpages updated_on' => 'Modificado el',
	'field Companies created_by_id' => 'Creado por',
	'field Companies updated_by_id' => 'Actualizado por',
	'field Contacts company_id' => 'Empresa',
	'field Contacts created_by_id' => 'Creado por',
	'field Contacts updated_by_id' => 'Actualizado por',
	'field MailContents created_by_id' => 'Creado por',
	'field MailContents updated_by_id' => 'Actualizado por',
	'field ProjectEvents created_by_id' => 'Creado por',
	'field ProjectEvents updated_by_id' => 'Actualizado por',
	'field ProjectFiles created_by_id' => 'Creado por',
	'field ProjectFiles updated_by_id' => 'Actualizado por',
	'field ProjectMilestones created_by_id' => 'Creado por',
	'field ProjectMilestones updated_by_id' => 'Actualizado por',
	'field ProjectMilestones assigned_to_company_id' => 'Asignado a la empresa',
	'field ProjectMilestones assigned_to_user_id' => 'Asignado al usuario',
	'field ProjectMessages created_by_id' => 'Creado por',
	'field ProjectMessages updated_by_id' => 'Actualizado por',
	'field ProjectMessages milestone_id' => 'Hito',
	'field ProjectTasks created_by_id' => 'Creado por',
	'field ProjectTasks updated_by_id' => 'Actualizado por',
	'field ProjectTasks milestone_id' => 'Hito',
	'field ProjectTasks assigned_to_company_id' => 'Asignada a la empresa',
	'field ProjectTasks assigned_to_user_id' => 'Asignada al usuario',
	'field ProjectTasks completed_by_id' => 'Completado por',
	'field ProjectTasks repeat_by' => 'Repetir por',
	'field ProjectTasks repeat_end' => 'Fin de repetición',
	'field ProjectTasks repeat_num' => 'Número de repeticiones',
	'field ProjectTasks repeat_forever' => 'Repetir para siempre',
	'field ProjectTasks repeat_d' => 'Día de repetición',
	'field ProjectTasks repeat_m' => 'Mes de repetición',
	'field ProjectTasks repeat_y' => 'Año de repetición',
	'field ProjectTasks state' => 'Estado',
	'field Users created_by_id' => 'Creado por',
	'field Users updated_by_id' => 'Actualizado por',
	'field Users company_id' => 'Empresa',
	'field ProjectWebpages created_by_id' => 'Creado por',
	'field ProjectWebpages updated_by_id' => 'Actualizado por',
	'field Projects created_by_id' => 'Creado por',
	'field Projects updated_by_id' => 'Actualizado por',
	'field Projects completed_by_id' => 'Completado por',
	'field Users archived_on' => 'Archivado el',
	'field Users archived_by_id' => 'Archivado por',
	'field ProjectWebpages archived_on' => 'Archivado el',
	'field ProjectWebpages archived_by_id' => 'Archiado por',
	'field ProjectEvents repeat_dow' => 'Día de semana de la repetición',
	'field ProjectEvents repeat_mjump' => 'Salto de mes de la repetición',
	'field ProjectEvents repeat_wnum' => 'Número de semana de la repetición',
	'field Users can_manage_time' => 'Puede manejar tiempo',
	'field Users can_add_mail_accounts' => 'Puede agregar cuentas de correo',
	'field MailContents received_date' => 'Fecha de recibido',
	'field Users type' => 'Tipo',
); ?>

==> fengoffice_2.0.0.zip: fengoffice/language/es_es/fields.php <==
<?php return array(
	'field Companies name' => 'Nombre',
	'field Companies address' => 'Dirección',
	'field Companies address2' => 'Dirección 2',
	'field Companies city' => 'Ciudad',
	'field Companies state' => 'Estado',
	'field Companies zipcode' => 'Código postal',
	'field Companies country' => 'País',
	'field Companies phone_number' => 'Teléfono',
	'field Companies fax_number' => 'Fax',
	'field Companies email' => 'Correo electrónico',
	'field Companies homepage' => 'Sitio web',
	'field Companies notes' => 'Notas',
	'field Companies created_on' => 'Creado',
	'field Companies updated_on' => 'Actualizado',
	'field Companies archived_on' => 'Archivado',
	'field Companies archived_by_id' => 'Archivado por',
	'field Contacts firstname' => 'Nombre',
	'field Contacts lastname' => 'Apellido',
	'field Contacts email' => 'Correo electrónico',
	'field Contacts w_web_page' => 'Sitio web del trabajo',
	'field Contacts w_address' => 'Dirección del trabajo',
	'field Contacts w_city' => 'Ciudad del trabajo',
	'field Contacts w_state' => 'Estado del trabajo',
	'field Contacts w_zipcode' => 'Código postal del trabajo',
	'field Contacts w_country' => 'País del trabajo',
	'field Contacts w_phone_number' => 'Teléfono del trabajo',
	'field Contacts w_phone_number2' => 'Teléfono 2 del trabajo',
	'field Contacts w_fax_number' => 'Fax del trabajo',
	'field Contacts w_assistant_number' => 'Asistente del trabajo',
	'field Contacts w_callback_number' => 'Llamado del trabajo',
	'field Contacts h_web_page' => 'Sitio web del hogar',
	'field Contacts h_address' => 'Dirección del hogar',
	'field Contacts h_city' => 'Ciudad del hogar',
	'field Contacts h_state' => 'Estado del hogar',
	'field Contacts h_zipcode' => 'Código postal del hogar',
	'field Contacts h_country' => 'País del hogar',
	'field Contacts h_phone_number' => 'Teléfono del hogar',
	'field Contacts h_phone_number2' => 'Teléfono 2 del hogar',
	'field Contacts h_fax_number' => 'Fax del hogar',
	'field Contacts h_mobile_number' => 'Teléfono móvil del hogar',
	'field Contacts h_pager_number' => 'Pager del hogar',
	'field Contacts o_web_page' => 'Otro sitio web',
	'field Contacts o_address' => 'Otra dirección',
	'field Contacts o_city' => 'Otra ciudad',
	'field Contacts o_state' => 'Otro estado',
	'field Contacts o_zipcode' => 'Otro código postal',
	'field Contacts o_country' => 'Otro país',
	'field Contacts o_phone_number' => 'Otro teléfono',
	'field Contacts o_phone_number2' => 'Otro teléfono 2',
	'field Contacts o_fax_number' => 'Otro fax',
	'field Contacts o_birthday' => 'Fecha de nacimiento',
	'field Contacts email2' => 'Dirección de correo 2',
	'field Contacts email3' => 'Dirección de correo 3',
	'field Contacts job_title' => 'Título',
	'field Contacts department' => 'Departamento',
	'field Contacts middlename' => 'Segundo nombre',
	'field Contacts notes' => 'Notas',
	'field Contacts created_on' => 'Creado',
	'field Contacts updated_on' => 'Actualizado',
	'field Contacts archived_on' => 'Archivado',
	'field Contacts archived_by_id' => 'Archivado por',
	'field MailContents from' => 'De',
	'field MailContents from_name' => 'De nombre',
	'field MailContents to' => 'Para',
	'field MailContents date' => 'Fecha',
	'field MailContents sent_date' => 'Fecha de enviado',
	'field MailContents subject' => 'Asunto',
	'field MailContents content' => 'Contenido',
	'field MailContents body' => 'Cuerpo',
	'field MailContents body_plain' => 'Cuerpo plano',
	'field MailContents body_html' => 'Cuerpo HTML',
	'field MailContents has_attachments' => 'Tiene adjuntos',
	'field MailContents size' => 'Tamaño',
	'field MailContents state' => 'Estado',
	'field MailContents is_deleted' => 'Eliminado',
	'field MailContents is_shared' => 'Compartido',
	'field MailContents imap_folder_name' => 'Nombre de carpeta IMAP',
	'field MailContents account_email' => 'Cuenta de correo',
	'field MailContents created_on' => 'Creado',
	'field MailContents cc' => 'CC',
	'field MailContents bcc' => 'BCC',
	'field MailContents archived_on' => 'Archivado',
	'field MailContents archived_by_id' => 'Archivado por',
	'field MailContents sync' => 'Sincronizado',
	'field ProjectEvents duration' => 'Fin',
	'field ProjectEvents start' => 'Comienzo',
	'field ProjectEvents subject' => 'Asunto',
	'field ProjectEvents repeat_forever' => 'Repetir para siempre',
	'field ProjectEvents description' => 'Descripción',
	'field ProjectEvents private' => 'Privado',
	'field ProjectEvents repeat_end' => 'Fin de repetición',
	'field ProjectEvents repeat_num' => 'Número de repetición',
	'field ProjectEvents repeat_d' => 'Día de repetición',
	'field ProjectEvents repeat_m' => 'Mes de repetición',
	'field ProjectEvents repeat_y' => 'Año de repetición',
	'field ProjectEvents repeat_h' => 'Hora de repetición',
	'field ProjectEvents created_on' => 'Creado',
	'field ProjectEvents updated_on' => 'Actualizado',
	'field ProjectEvents archived_on' => 'Archivado',
	'field ProjectEvents archived_by_id' => 'Archivado por',
	'field ProjectFiles filename' => 'Nombre de archivo',
	'field ProjectFiles description' => 'Descripción',
	'field ProjectFiles is_important' => 'Importante',
	'field ProjectFiles is_locked' => 'Bloqueado',
	'field ProjectFiles is_visible' => 'Visible',
	'field ProjectFiles expiration_time' => 'Tiempo de expiración',
	'field ProjectFiles comments_enabled' => 'Comentarios habilitados',
	'field ProjectFiles anonymous_comments_enabled' => 'Comentarios anónimos habilitados',
	'field ProjectFiles url' => 'Url',
	'field ProjectFiles created_on' => 'Creado',
	'field ProjectFiles updated_on' => 'Actualizado',
	'field ProjectFiles checked_out_on' => 'Bloqueado',
	'field ProjectFiles archived_on' => 'Archivado',
	'field ProjectFiles archived_by_id' => 'Archivado por',
	'field ProjectFileRevisions filecontent' => 'Contenido del documento',
	'field ProjectMilestones name' => 'Nombre',
	'field ProjectMilestones description' => 'Descripción',
	'field ProjectMilestones due_date' => 'Fecha de límite',
	'field ProjectMilestones completed_on' => 'Completado',
	'field ProjectMilestones is_template' => 'Es plantilla',
	'field ProjectMilestones created_on' => 'Creado',
	'field ProjectMilestones updated_on' => 'Actualizado',
	'field ProjectMilestones archived_on' => 'Archivado',
	'field ProjectMilestones archived_by_id' => 'Archivado por',
	'field ProjectMessages title' => 'Título',
	'field ProjectMessages text' => 'Texto',
	'field ProjectMessages additional_text' => 'Texto adicional',
	'field ProjectMessages is_important' => 'Es importante',
	'field ProjectMessages comments_enabled' => 'Comentarios habilitados',
	'field ProjectMessages anonymous_comments_enabled' => 'Comentarios anónimos habilitados',
	'field ProjectMessages created_on' => 'Creado',
	'field ProjectMessages updated_on' => 'Actualizado',
	'field ProjectMessages archived_on' => 'Archivado',
	'field ProjectMessages archived_by_id' => 'Archivado por',
	'field ProjectTasks text' => 'Texto',
	'field ProjectTasks completed_on' => 'Completada',
	'field ProjectTasks due_date' => 'Fecha de límite',
	'field ProjectTasks start_date' => 'Fecha de comienzo',
	'field ProjectTasks created_on' => 'Creada',
	'field ProjectTasks updated_on' => 'Actualizada',
	'field ProjectTasks order' => 'Orden',
	'field ProjectTasks title' => 'Título',
	'field ProjectTasks started_on' => 'Comenzado',
	'field ProjectTasks priority' => 'Prioridad',
	'field ProjectTasks assigned_on' => 'Asignado',
	'field ProjectTasks time_estimate' => 'Tiempo estimado',
	'field ProjectTasks is_template' => 'Es plantilla',
	'field ProjectTasks archived_on' => 'Archivado',
	'field ProjectTasks archived_by_id' => 'Archivado por',
	'field ProjectTasks object_subtype' => 'Tipo de objeto',
	'field Users username' => 'Nombre de usuario',
	'field Users email' => 'Correo electrónico',
	'field Users display_name' => 'Nombre desplegado',
	'field Users title' => 'Título',
	'field Users created_on' => 'Creado',
	'field Users updated_on' => 'Actualizado',
	'field Users last_login' => 'Última conexión',
	'field Users last_visit' => 'Última visita',
	'field Users last_activity' => 'Última actividad',
	'field Users can_edit_company_data' => 'Puede editar información de empresa propietaria',
	'field Users can_manage_workspaces' => 'Puede manejar áreas de trabajo',
	'field Users can_manage_security' => 'Puede manejar seguridad',
	'field Users can_manage_configuration' => 'Puede manejar configuración',
	'field Users auto_assign' => 'Auto asignar',
	'field Users can_manage_contacts' => 'Puede manejar contactos',
	'field Users can_manage_templates' => 'Puede manejar plantillas',
	'field Users can_manage_reports' => 'Puede manejar reportes',
	'field ProjectWebPages url' => 'Url',
	'field ProjectWebPages title' => 'Título',
	'field ProjectWebPages description' => 'Descripción',
	'field ProjectWebPages created_on' => 'Creado',
	'field ProjectWebPages updated_on' => 'Actualizado',
	'field ProjectWebPages archived_on' => 'Archivado',
	'field ProjectWebPages archived_by_id' => 'Archivado por',
	'field Projects name' => 'Nombre',
	'field Projects description' => 'Descripción',
	'field Projects show_description_in_overview' => 'Mostrar descripción en vista general',
	'field Projects completed_on' => 'Completado',
	'field Projects created_on' => 'Creado',
	'field Projects updated_on' => 'Actualizado',
	'field Projects archived_on' => 'Archivado',
	'field Projects archived_by_id' => 'Archivado por',
	'field ProjectWebpages url' => 'Url',
	'field ProjectWebpages title' => 'Título',
	'field ProjectWebpages description' => 'Descripción',
	'field ProjectWebpages created_on' => 'Creado el',
	'field ProjectWebpages updated_on' => 'Modificado el',
	'field Companies created_by_id' => 'Creado por',
	'field Companies updated_by_id' => 'Actualizado por',
	'field Contacts company_id' => 'Empresa',
	'field Contacts created_by_id' => 'Creado por',
	'field Contacts updated_by_id' => 'Actualizado por',
	'field MailContents created_by_id' => 'Creado por',
	'field MailContents updated_by_id' => 'Actualizado por',
	'field ProjectEvents created_by_id' => 'Creado por',
	'field ProjectEvents updated_by_id' => 'Actualizado por',
	'field ProjectFiles created_by_id' => 'Creado por',
	'field ProjectFiles updated_by_id' => 'Actualizado por',
	'field ProjectMilestones created_by_id' => 'Creado por',
	'field ProjectMilestones updated_by_id' => 'Actualizado por',
	'field ProjectMilestones assigned_to_company_id' => 'Asignado a la empresa',
	'field ProjectMilestones assigned_to_user_id' => 'Asignado al usuario',
	'field ProjectMessages created_by_id' => 'Creado por',
	'field ProjectMessages updated_by_id' => 'Actualizado por',
	'field ProjectMessages milestone_id' => 'Hito',
	'field ProjectTasks created_by_id' => 'Creado por',
	'field ProjectTasks updated_by_id' => 'Actualizado por',
	'field ProjectTasks milestone_id' => 'Hito',
	'field ProjectTasks assigned_to_contact_id' => 'Asignada a',
	'field ProjectTasks completed_by_id' => 'Completado por',
	'field ProjectTasks repeat_by' => 'Repetir por',
	'field ProjectTasks repeat_end' => 'Fin de repetición',
	'field ProjectTasks repeat_num' => 'Número de repeticiones',
	'field ProjectTasks repeat_forever' => 'Repetir para siempre',
	'field ProjectTasks repeat_d' => 'Día de repetición',
	'field ProjectTasks repeat_m' => 'Mes de repetición',
	'field ProjectTasks repeat_y' => 'Año de repetición',
	'field ProjectTasks percent_completed' => 'Percentaje completado',
	'field Users created_by_id' => 'Creado por',
	'field Users updated_by_id' => 'Actualizado por',
	'field Users company_id' => 'Empresa',
	'field ProjectWebpages created_by_id' => 'Creado por',
	'field ProjectWebpages updated_by_id' => 'Actualizado por',
	'field Projects created_by_id' => 'Creado por',
	'field Projects updated_by_id' => 'Actualizado por',
	'field Projects completed_by_id' => 'Completado por',
	'field Users archived_on' => 'Archivado el',
	'field Users archived_by_id' => 'Archivado por',
	'field ProjectWebpages archived_on' => 'Archivado el',
	'field ProjectWebpages archived_by_id' => 'Archiado por',
	'field ProjectEvents repeat_dow' => 'Día de semana de la repetición',
	'field ProjectEvents repeat_mjump' => 'Salto de mes de la repetición',
	'field ProjectEvents repeat_wnum' => 'Número de semana de la repetición',
	'field Users can_manage_time' => 'Puede administrar Tiempos de trabajo',
	'field Users can_add_mail_accounts' => 'Puede agregar cuentas de correo',
	'field MailContents received_date' => 'Fecha de recibido',
	'field Users type' => 'Tipo',
); ?>
